.. _lfdocs-conf:

lfdocs-conf
===========

Linux Foundation Sphinx documentation common configuration project.

This package is a set of default configurations for Linux Foundation
projects that use Sphinx to share a common centralized configuration.

Contents:

.. toctree::
    :maxdepth: 2

    release-notes
    install
    config

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
